@@ -85,6 +85,8 @@ int extract_version(const char * file, int force, char * version) {
 
 	int end;
 
+	int i;
+
 	if ( force )
 		end = MAX_SIZE;
 	else
@@ -142,7 +144,13 @@ int extract_version(const char * file, int force, char * version) {
 	if ( msize > end )
 		msize = end;
 
-	mptr = calloc(1, msize);
+	for ( i = 0; i < 10; ++i ) {
+		mptr = calloc(1, msize);
+		if ( mptr )
+			break;
+		/* Cannot allocate memory, try again */
+		sleep(1);
+	}
 
 	if ( ! mptr ) {
 		fprintf(stderr, "Cannot allocate memory\n");
@@ -150,7 +158,15 @@ int extract_version(const char * file, int force, char * version) {
 		return -1;
 	}
 
-	if ( read(fd, mptr, msize) == -1 ) {
+	for ( i = 0; i < 10; ++i ) {
+		ret = read(fd, mptr, msize);
+		if ( ret != -1 || errno != ENOMEM )
+			break;
+		/* Cannot allocate memory, try again */
+		sleep(1);
+	}
+
+	if ( ret == -1 ) {
 		fprintf(stderr, "Cannot read %s: %s\n", file, strerror(errno));
 		free(mptr);
 		close(fd);
